/* [drawer] */
// inner width
dw = 170;
// inner height
dh = 25;
// inner depth
dd = 90;
// walls thickness
dt = 2;

/* [ casing ] */
// Amount of drawers
cd = 4;
// walls tickness
ct = 3.8;

/* [ print settings ] */
// printing tolerance
pt = 0.5;
// What to print
to_print = "casing"; // [casing, drawer]


casing_height = dh+dt+ct+pt;
casing_width = dw+ct*3+pt*2;
casing_depth = dd+ct+pt;


if (to_print == "drawer") {
  drawer();
}


if (to_print == "casing") {
  for (i=[1:1:cd]) {
    translate([0,0,ct+casing_height*(i-1)]) {
      translate([ct+pt,0,0]) %drawer();
      casing();
    }
  }
  cube([casing_width,casing_depth+ct,ct]);
  translate([0,0,casing_height*cd+ct])cube([casing_width,casing_depth+ct,ct]);
}


module casing () {
  // left side
  union() {
    cube([ct, casing_depth, casing_height]);
    translate([ct,dt+pt,dh+dt+pt*2]) cube([ct, dd+ct-dt, ct-pt]);
    translate([0,casing_depth,0]) cube([ct*2-pt, ct, casing_height]);
  }
  
  // right side
  translate([dw+ct*2+pt*2,0,0]) {
    cube([ct, casing_depth, casing_height]);
    translate([-ct,dt+pt,dh+dt+pt*2]) cube([ct, dd+ct-dt, ct-pt]);
    translate([-ct+pt,casing_depth,0]) cube([ct*2-pt, ct, casing_height]);
  }
  
  // back stabilizer
  translate([ct*2-pt,casing_depth,dh-dt-pt-(casing_height-ct)/2])
    cube([dw-ct+pt*4,ct,ct*2]);
}



module drawer () {
  w = dw+dt*2;
  h = dh+dt;
  d = dd+dt*2;
  
  hw = w/32;
  hh = (h+ct)/2;
  
  difference() {
    union() {
      cube([w, d, h]); // outer perimeter
      cube([w, dt, h+ct]); // front panel
      d();
    }
    translate([dt,dt,dt]) cube([dw,dd,dh]);
  }
  
  module d () {
      translate([(w-hw)/2,0,h/6]) {
        difference() {
          rotate([45,0,0]) cube([hw,hh,hh]);
          translate([0,-hh-hh/2,0]) cube([hw,hh,hh]);
        }
      }
  }
}